django-thorbanks
================

Django app for integrating Estonian banklinks into your project.
Based on https://github.com/truevision/django_banklink

Supports banks that use iPizza protocol - Swedbank, SEB, Danske, LHV.
